/*
PET CARE PROJECT
COUNTY BUSINESS PATTERNS ANALYSIS

THIS DO FILE APPENDS THE COUNTY BUSINESS PATTERNS FILES (COUNTY LEVEL)
FOR 1990-2013 TO CREATE A TIME SERIES DATASET
*/

#delimit;
clear;
set more off;


local cnt=1;
local list "90 91 92 93 94 95 96 97 98 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13";

foreach yr of local list{;
	if `cnt'<11{;
		local yearn = "19" + "`yr'";
	};
	else if `cnt'>10{;
		local yearn = "20" + "`yr'";
	};

	cd "<Raw CBP data>";
	di "**********************************************************************";
	di "`yearn'";
	di "**********************************************************************";
	insheet using cbp`yr'co.txt, clear;

	if `yearn'<1998{;
		destring sic, force replace ignore("-" "/" "\");
		replace sic=1 if sic==.;
		rename sic sector;
	};
	else {;
		destring naics, force replace ignore("-" "/");
		replace naics=1 if naics==.;
		rename naics sector;
	};

	keep fipstate fipscty sector emp ap est censtate cencty;
	gen yr=`yearn';
	order yr;

	keep if sector==1 | //all sectors
		 sector==6211 | // physician offices
		 sector==6212 | // dentist offices
		 sector==6213 | // all other health professional offices
		 sector==6221 | // general and surgical hospitals
		 sector==6231 | // nursing homes
		 sector==8010 | sector==8030 | // SIC doctor office
		 sector==8020 | // SIC dentist office
		 sector==8040 | // SIC other offices
		 sector==8060 | // SIC hospitals
		 sector==8050 | // SIC nursing homes
		 sector==81291 | // pet services
		 sector==54194 | // Veterinarian
		 sector==740 | // SIC Veterinarian
		 sector==750; // SIC pet services

	label define sectlab 1 "ctytot" 6211 "phys" 6212 "dentist" 6213 "oth" 
		6221 "hosp" 6231 "nursng" 54194 "vet" 81291 "petserv" 
		8010 "phys_sic" 8020 "dent_sic" 8030 "ost_sic" 
		8040 "oth_sic" 8050 "nurs_sic" 8060 "hosp_sic" 740 "vet_sic" 
		750 "petserv_sic", replace;

	label values sector sectlab;

	if `cnt'==1{;
		save "$new\cbpfile.dta", replace;
	};
	else {;
		tempfile tempcbp;
		save `tempcbp', replace;
		use "$new\cbpfile.dta", replace;
		append using `tempcbp';
		save "$new\cbpfile.dta", replace;		
	};
	local cnt=`cnt'+1;

};
*Year loop (foreach) ends;

gen phys = inrange(sector,6211,6213) | inrange(sector,8010,8040);
gen hosp = sector==6221 | sector==6231 | sector==8050 | sector==8060;
gen vet = sector==740 | sector==54194;
gen nonvet = sector==750 | sector==81291;
gen cty = sector==1;

collapse (sum) emp ap est cty, by (yr fipstate fipscty phys hosp vet nonvet);
sort fipstate fipscty yr ;

gen type="all";
replace type="phys" if phys==1;
replace type="hosp" if hosp==1;
replace type="vet" if vet==1;
replace type="nonvet" if nonvet==1;

drop cty phys hosp vet nonvet;

order fipstate fipscty yr type;
sort fipstate fipscty yr type;

saveold "$new\cbpfile.dta", replace;

*END CODE;
