/*
PET CARE PROJECT
VETERINARIAN BILLING DATA

THIS DO FILE STARTS FROM THE RAW BILLING DATA PROVIDED BY THE VETERINARIAN COMPANY AND PRODUCES A 
DATA FILE - "VET_BILLING". IT IS A CLEANED MONTHLY SPENDING FILE FOR THE LAST YEAR OF LIFE OF DOGS THAT
WERE DIAGNOSED WITH LYMPHOMA. IT THEN PRODUCES SUMMARY STATS FOR THE END-OF-LIFE SPENDING PATTERN.
*/

#delimit;
clear;

cd "<raw vet data>";

*Start with raw data and clean it;
import excel using FNA.xlsx, sheet("Treatments") firstrow;

rename PatientID patid;
rename BIRTHDATE birthdt;
rename DECEASED_DATE deathdt;
rename WEIGHT wgt;
rename SEX sex;
rename SPECIES_NAME species;
rename BREED_NAME breed;
rename COLOR_NAME color;
rename TreatmentCode trcode;
rename TreatmentName trname;
rename DATE_PERFORMED trdate;
rename ENTERED_PRICE trprice;
rename ProfitCenter prcenter;
rename QTY qty;
rename UNIT_OF_MEASURE unit;
rename EmployeeID empid;
rename CITY_NAME owncity;
rename ZIPCODE ownzip;

count if species!="Canine";
if r(N)==0 drop species;

*Drop empty line items;
drop if trprice==0;

*Exclude non-healthcare categories;
*Drop mortuary, merchandise and flea;
drop if regexm(prcenter,"Flea")==1 | regexm(prcenter,"Mortuary")==1 | 
	regexm(prcenter,"Merch")==1;

*drop useless vars;
drop qty unit ownzip owncity empid color breed birthdt;

tempfile purchase_data;
save `purchase_data', replace;
*------------------------------------------------------------------------------;

*Create patient level file;
sort patid;
by patid: keep if _n==1;
keep patid deathdt sex;

gen sexcod = (sex=="MN" | sex=="M");
replace sexcod=. if sex!="FS" & sex!="F" & sex!="MN" & sex!="M";
label var sexcod "Male";

gen died = (deathdt!="NULL");
label var died "Died 2011-2014";

gen dd = date(deathdt,"DMY"); 
format dd %td; //Assume missing values are alive

tempfile fnabypat;
save `fnabypat', replace;
*------------------------------------------------------------------------------;
*USE DRUGS TO IDENTIFY COURSE OF TREATMENT (CHEMOTHERAPY)
use `purchase_data', clear;

gen trnamelow = lower(trname);

**CHEMOTHERAPY PROCEDURES**;

gen ind_chemo = regexm(trnamelow, "chemo") & regexm(trnamelow,"doxo")==0;

/* contains                 CHEMO Panel |         29        3.85        3.85
        Cbc W/Differential - Chemo Stat |        253       33.55       37.40
      Cbc W/O Differential - Chemo Stat |         46        6.10       43.50
                Chemo Procedure In-Pat. |          2        0.27       43.77
             Chemo Procedure Outpatient |         84       11.14       54.91
                Chemo Procedure Phaseal |        147       19.50       74.40
                         Chemo- Iv Cath |         80       10.61       85.01
               Chemo-Butterfly Catheter |         43        5.70       90.72      
----------------------------------------+-----------------------------------
                                  Total |        684      100.00
*/

gen ind_pred = regexm(trnamelow, "prednis");

/*
                          TreatmentName |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
                        O: Prednisolone |          2        0.67        0.67
                          O: Prednisone |          8        2.68        3.34
                         O: Prednisone  |          1        0.33        3.68
                          O:Prednisone  |          1        0.33        4.01
                       O:own prednisone |          4        1.34        5.35
                          O:prednisone  |          1        0.33        5.69
     Prednisolone 10mg/ml Sol Rx per ml |          1        0.33        6.02
Prednisolone 5mg Chewable Chicken In .. |          1        0.33        6.35
   Prednisolone 5mg Chewable Chicken Rx |          7        2.34        8.70
               Prednisolone 5mg In Hosp |          2        0.67        9.36
                    Prednisolone 5mg Rx |         45       15.05       24.41
             Prednisolone 5mg tablet Rx |          4        1.34       25.75
      Prednisolone Inj., 50mg/Ml Per Mg |         19        6.35       32.11
                Prednisone 20mg In Hosp |          6        2.01       34.11
                     Prednisone 20mg Rx |        193       64.55       98.66
              Prednisone 5mg tablets Rx |          2        0.67       99.33
                 Prednisone Tab 1 Mg Rx |          1        0.33       99.67
                   prednisolone 50mg/ml |          1        0.33      100.00
				   ----------------------------------------+-----------------------------------
                                  Total |        299      100.00
*/

gen ind_vinc = regexm(trnamelow, "vinc");
/*
                          TreatmentName |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
             Vincristine 1mg/Ml, Per Ml |        135      100.00      100.00
*/

gen ind_cycl = regexm(trnamelow, "cyclop");
/*
                          TreatmentName |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
          Cyclophosphamide 25mg In Hosp |          2        1.74        1.74
               Cyclophosphamide 25mg Rx |         17       14.78       16.52
       Cyclophosphamide 500mg, Per Vial |         33       28.70       45.22
               Cyclophosphamide 50mg Rx |         21       18.26       63.48
----------------------------------------+-----------------------------------
                                  Total |         73      100.00
			   */

gen ind_dox = regexm(trnamelow, "doxo");
/*
                          TreatmentName |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
             Doxorubicin 2mg/ml, per ml |          3        4.11        4.11
       Doxorubicin Chemo 2mg/Ml, Per Mg |         70       95.89      100.00
----------------------------------------+-----------------------------------
                                  Total |         73      100.00
*/

gen ind_lom = regexm(trnamelow, "lomus");

/*
                          TreatmentName |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
                 Lomustine 10mg In Hosp |          9       20.93       20.93
                      Lomustine 10mg Rx |         16       37.21       58.14
                 Lomustine 40mg In Hosp |          9       20.93       79.07
                      Lomustine 40mg Rx |          9       20.93      100.00
----------------------------------------+-----------------------------------
                                  Total |         43      100.00
*/

gen ind_aspar = regexm(trnamelow, "aspar");
replace ind_aspar = 1 if regexm(trnamelow, "elsp");

/*
                          TreatmentName |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
            Asparaginase 10,000 IU vial |          5       10.87       10.87
       Asparaginase 5,000 IU/ml, per ml |          1        2.17       13.04
                  Elspar 10,000 IU vial |         24       52.17       65.22
             Elspar 10,000 IU/10ml vial |         16       34.78      100.00
----------------------------------------+-----------------------------------
                                  Total |         46      100.00
*/

gen ind_iv = (regexm(trname,"IV") | regexm(trname,"Iv"));
/*
                          TreatmentName |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
                IV Fluids: Add Dextrose |          6        5.77        5.77
                     IV Fluids: Add KCL |         95       91.35       97.12
                  IV Fluids: Add Vit. B |          3        2.88      100.00
----------------------------------------+-----------------------------------
                                  Total |        104      100.00
*/

gen ind_euth = regexm(trnamelow, "euth");
/*
----------------------------------------+-----------------------------------
                             Euthanasia |         19       13.48       13.48
                  Euthanasia - Catheter |          7        4.96       18.44
                  Euthanasia - Sedation |         19       13.48       31.91
            Euthanasia Solution, Per Ml |          1        0.71       32.62
                      Euthanasia per ml |         84       59.57       92.20
           Euthanasia per ml (In House) |         11        7.80      100.00
----------------------------------------+-----------------------------------
                                  Total |        141      100.00
*/

gen ind_fna = regexm(trnamelow,"fine needle");

gen items=1;

collapse (sum) items trprice ind_fna ind_chemo ind_pred ind_vinc ind_cycl 
	ind_dox ind_lom ind_aspar ind_iv ind_euth, by (patid trdate);

gen visits=1;

collapse (sum) items visits ind_fna trprice ind_chemo ind_pred ind_vinc 
	ind_cycl ind_dox ind_lom ind_aspar ind_iv ind_euth, by (patid);

label var visits "Num visits";
label var trprice "Total spent";
label var ind_euth "Euthanized";
label var ind_pred "Prednisolone";
label var ind_vinc "Vincristine";
label var ind_cycl "Cyclophosphamide";
label var ind_dox "Doxorobucin";
label var ind_lom "Lomustine";
label var ind_aspar "Asparaginase";
label var ind_iv "IV fluids";
label var ind_chemo "Chemotherapy";

*Reset to 0-1 indicator vars;
local names "ind_fna ind_chemo ind_pred ind_vinc ind_cycl ind_dox ind_lom ind_aspar ind_euth ind_iv";
foreach nm of local names {;
	replace `nm'=1 if `nm'>1;
};

*More indicator variables;
gen lymdrugs = (ind_cycl | ind_dox | ind_vinc | ind_lom | ind_aspar );
gen onlypred = (ind_pred==1 & ind_chemo==0 & lymdrugs==0);

gen status=1;
replace status=2 if onlypred==1;
replace status=3 if lymdrugs;

label define stat 1 "Non Lymph treatment" 2 "Only Prednis" 3 "Chemotherapy";
label values status stat;

merge 1:1 patid using `fnabypat';
drop _m;

tempfile vet_bill2;
saveold `vet_bill2', replace;

*------------------------------------------------------------------------------;
use `purchase_data', clear;
keep patid trprice trdate; 

merge m:1 patid using `vet_bill2';
drop if _m==2;
drop _m;

*Create patient level file with death status;
preserve;
	sort patid;
	keep patid dd died;
	by patid: keep if _n==1;
	tempfile deathdata;
	save `deathdata';
restore;

*Create patient level file with treatment status;
preserve;
	sort patid;
	keep patid ind_euth status;
	by patid: keep if _n==1;
	tempfile tr_stat;
	save `tr_stat';
restore;

*collapse by visit;
collapse (sum) trprice, by (patid trdate);

*Get death date and drop those alive at the end of period;
merge m:1 patid using `deathdata', keepusing (dd died);
drop if died==0;
drop _m;

gen daydiff = dd - trdate;

*Simplification: Assume a month is 30 days, this ensures no bias against the
*month of death;
gen month = int(daydiff/30)+1;
	
*Drop those patients for whom we observe less than 1 year of data;
bysort patid: gen recent = daydiff[1]<365;
drop if recent==1;

drop if daydiff>365;
replace month = 12 if month>12;

*drop negative values (ordinarily cannot have discount > charge!);
drop if trprice<0;

*Get CPI adjuster (relative to 2012 as base);
gen ref_yr = year(trdate);
merge m:1 ref_yr using "$new\cpifile.dta", keepusing(cpiu);
drop if _m==2;
drop _m;

replace trprice = trprice/cpi;

*Collapse by month;
collapse (sum) trprice died, by (patid month);

*Bring in treatment status and euthanasia info;
merge m:1 patid using `tr_stat', keepusing (ind_euth status);
drop if _m==2;
drop _m;

gen treated = (status==3);

label var trprice "Spending ($)";

drop died ind_euth;

keep if treated==1;
drop treated status;
ren trprice spending;

reshape wide spending, i(patid) j(month);
recode spending* (mis=0);

saveold "$new\vetfile", replace;

*SIMPLE LINE CHART OF MEDIAN AND MEAN;
tabstat spending1 spending2 spending3 spending4 spending5 spending6 spending7
	spending8 spending9 spending10 spending11 spending12, 
	col(stat) stat(mean p50 p75 p90);

*END CODE;
